@@ -1,5 +1,3 @@
-context("calc_TLLxTxRatio")
-
 ##load package example data
 data(ExampleData.BINfileData, envir = environment())
 
@@ -20,19 +18,22 @@ temp <- calc_TLLxTxRatio(Lx.data.signal,
                            signal.integral.min, signal.integral.max)
 
 test_that("check class and length of output", {
-  
-  expect_equal(is(temp), c("RLum.Results", "RLum"))
+  testthat::skip_on_cran()
+  local_edition(3)
+
+  expect_s4_class(temp, "RLum.Results")
   expect_equal(length(temp), 1)
-  
+
 })
 
 test_that("check values from output", {
-  
-  
+  testthat::skip_on_cran()
+  local_edition(3)
+
   results <- get_RLum(temp)
-  
+
   expect_equal(length(results), 10)
-  
+
   expect_equal(results$LnLx, 257042)
   expect_equal(results$LnLx.BG, 4068)
   expect_equal(results$TnTx, 82298)
@@ -43,5 +44,5 @@ test_that("check values from output", {
   expect_equal(round(results$net_TnTx.Error,2), 21449.72)
   expect_equal(round(results$LxTx, digits =  6), 3.187877)
   expect_equal(round(results$LxTx.Error, digits = 6), 1.485073)
-  
-})
\ No newline at end of file
+
+})
